import{s as a,b as t,a as r,S as s}from"./Ql9eLH1K.js";import{_ as i}from"./BnimKDg3.js";var _={parser:r,get db(){return new s(2)},renderer:t,styles:a,init:i(e=>{e.state||(e.state={}),e.state.arrowMarkerAbsolute=e.arrowMarkerAbsolute},"init")};export{_ as diagram};
